@@ -1,7 +1,9 @@
 package k8s
 
 import (
+	"crypto/md5"
 	"encoding/json"
+	"fmt"
 
 	"github.com/pkg/errors"
 	uns "k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -20,3 +22,13 @@ func ToUnstructured(obj interface{}) (*uns.Unstructured, error) {
 	}
 	return u, nil
 }
+
+// CalculateHash computes MD5 sum of the JSONfied object passed as obj.
+func CalculateHash(obj interface{}) (string, error) {
+	configStr, err := json.Marshal(obj)
+	if err != nil {
+		return "", err
+	}
+	configSum := md5.Sum(configStr)
+	return fmt.Sprintf("%x", configSum), nil
+}
